//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[pon](pon.md)

# pon

[common]\
val [pon](pon.md): [ShantenWithGot](../-shanten-with-got/index.md)?

碰后的向听信息（若无法碰则为null）
